@@ -1,9 +1,15 @@
+from venv import create
 import click
 import requests
 import json
 from git import Repo
 import os
 import sys 
+from pydriller import Git
+from libs import iterate_over_diffs
+from libs import put_into_df
+from libs import create_prompt
+
 @click.command()
 @click.option('--count', default=1, help='Number of greetings.')
 @click.option('--name', prompt='Your name',
@@ -32,10 +38,27 @@ def commit():
     # Get preds
     # Commit
     repo = Repo(os.getcwd())
-    # print(repo)
-    diff = repo.git.diff()
-    print("OK")
-    resp = requests.post('https://api.litcommit.com/predict/commit', json={"prompt": diff[0:2048]}) 
+
+    # commit current changes
+    repo.git.commit('-am',"pre commit")
+    # get last commit
+    gr = Git(os.getcwd())
+    commit = gr.get_head()
+
+    # get a LIST of parsed diffs, one entry per file
+    parsed_diffs = []
+    for mod in commit.modified_files:
+        parsed_diff = mod.diff_parsed
+        parsed_diffs.append(parsed_diff)
+
+    parsed_diffs_cleaned = iterate_over_diffs(parsed_diffs)
+    df = put_into_df(parsed_diffs_cleaned)
+    prompt = create_prompt(df)
+    click.echo("PROMPT")
+    click.echo(str(prompt))
+    
+
+    resp = requests.post('https://api.litcommit.com/predict/commit', json={"prompt": str(prompt)}) 
     # Then commit those
     # print(resp.status_code)
     # resp = resp.json()
@@ -67,4 +90,4 @@ def main():
     apis(prog_name="lit")
 
 if __name__=='__main__':
-    main()
+    main()
\ No newline at end of file
